@@ -123,8 +123,6 @@ class SessionAuth(object):
           method (str): method, e.g. local or google
           headers (dict): additional headers, such as Set-Cookie
         """
-        account.last_login = utcnow()
-
         # connexion doesn't support cookie auth. probably just as well,
         #  this forced me to implement a JWT design with nonce token
         # https://github.com/zalando/connexion/issues/791
@@ -162,6 +160,12 @@ class SessionAuth(object):
             if self.roles_from:
                 roles += self.get_roles(account.uid,
                                         member_model=self.roles_from)
+            try:
+                account.last_login = utcnow()
+                g.db.commit()
+            except Exception as ex:
+                logging.error(dict(message='DB operational error',
+                                   error=str(ex), **logmsg))
         else:
             roles = []
         if acc.apikey_id:
@@ -250,19 +254,21 @@ class SessionAuth(object):
                 cid = g.db.query(self.models.Contact).filter_by(
                     info=identity, type='email').one().id
             except Exception as ex:
-                msg = 'registration trouble, error=%s' % str(ex)
-                logging.error(dict(message=msg, **logmsg))
-                return dict(message=msg), 405
+                return db_abort(str(ex), msg=_(u'contact lookup'), **logmsg)
         else:
             person = self.models.Person(
                 id=gen_id(prefix='u-'), name=name, identity=identity,
                 status='active')
             uid = person.id
             cid = gen_id()
-            g.db.add(person)
-            g.db.add(self.models.Contact(id=cid, uid=uid, type='email',
-                                         info=identity))
-            g.db.commit()
+            try:
+                g.db.add(person)
+                g.db.add(self.models.Contact(id=cid, uid=uid, type='email',
+                                             info=identity))
+                g.db.commit()
+            except Exception as ex:
+                return db_abort(str(ex), rollback=True,
+                                msg=_(u'contact activation problem'), **logmsg)
             logging.info(dict(message=_(u'person added'), uid=uid, **logmsg))
         # If browser language does not match global default language, add
         # a profile setting
@@ -336,6 +342,7 @@ class SessionAuth(object):
         except Exception as ex:
             return db_abort(str(ex), action='auth_params')
         retval = dict(
+            account_id=account_id, uid=AccessControl().uid,
             resources=ServiceRegistry().find()['url_map'],
             settings_id=settings.get.id, totp=account.totp)
         storage_id = settings.get.default_storage_id
